#
# spec file for package syncthing
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           syncthing
Version:        0.14.26
Release:        1.13
Summary:        FOSS Continuous File Synchronisation
License:        MPL-2.0
Group:          Productivity/Networking/File-Sharing
Url:            https://syncthing.net/
Source:         https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-source-v%{version}.tar.gz
Source1:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-source-v%{version}.tar.gz.asc
Source2:        %{name}.keyring
Source3:        %{name}.firewall
BuildRequires:  go >= 1.5
BuildRequires:  systemd
BuildRequires:  systemd-rpm-macros

%description
Syncthing replaces proprietary sync and cloud services with
something open, trustworthy and decentralised. Your data is your
data alone and you deserve to choose where it is stored, if it is
shared with some third party and how it's transmitted over the
Internet.

%prep
%setup -q -n %{name}

cp -f %{SOURCE3} %{name}.firewall
%if !(0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200)
# Remove entries which only exist since systemd 215.
sed -i '/^RestartForceExitStatus=/d;s/^\(SuccessExitStatus=\).*$/\12/' \
  etc/linux-systemd/system/syncthing@.service
%endif

%build
mkdir -p build/src/ build/vendor/
export GOPATH="$PWD/build:$PWD/build/vendor"

mkdir -p build/src/github.com/%{name}/%{name}
ls | sed '/^build$/d' | xargs cp -at build/src/github.com/%{name}/%{name}
cp -a vendor build/vendor/src

pushd build/src/github.com/%{name}/%{name}/
go run build.go install all \
  -version v%{version} -no-upgrade
popd

%install
install -Dpm 0755 build/src/github.com/%{name}/%{name}/bin/%{name} \
  %{buildroot}%{_bindir}/%{name}
install -Dpm 0644 etc/linux-systemd/system/%{name}@.service        \
  %{buildroot}%{_unitdir}/%{name}@.service
install -Dpm 0644 etc/linux-systemd/system/%{name}-resume.service  \
  %{buildroot}%{_unitdir}/%{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
install -Dpm 0644 etc/linux-systemd/user/%{name}.service           \
  %{buildroot}%{_userunitdir}/%{name}.service
%endif
install -Dpm 0644 %{name}.firewall                                 \
  %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}

%pre
%service_add_pre %{name}-resume.service

%post
%service_add_post %{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%systemd_user_post %{name}.service
%endif

%preun
%service_del_preun %{name}@.service %{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%systemd_user_preun %{name}.service
%endif

%postun
%service_del_postun %{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%systemd_user_postun %{name}.service
%endif

%files
%defattr(-,root,root)
%doc AUTHORS CONDUCT.md CONTRIBUTING.md LICENSE README.md
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{name}
%{_bindir}/%{name}
%{_unitdir}/%{name}@.service
%{_unitdir}/%{name}-resume.service
%if 0%{?suse_version} > 1320 || 0%{?sle_version} >= 120200
%{_userunitdir}/%{name}.service
%endif

%changelog
* Mon Apr 10 2017 sor.alexei@meowr.ru
- Update to version 0.14.26:
  * Discovery errors are more clearly displayed in the GUI
    (gh#syncthing/syncthing#2344).
  * The language dropdown menu in the GUI is now correctly sorted
    (gh#syncthing/syncthing#3913).
  * When there are items that could not be synced, their full path
    is displayed in the GUI.
* Mon Mar 27 2017 sor.alexei@meowr.ru
- Update to version 0.14.25:
  * Improve "Pause All"/"Resume All" icons
    (gh#syncthing/syncthing#4003).
  * There are now mips and mipsle builds by default
    (gh#syncthing/syncthing#3959).
  * The "overwriting protected files" warning now correctly handles
    relative paths to the config directory
    (gh#syncthing/syncthing#3183).
  * The experimental KCP protocol for transfers over UDP has been
    merged, although it's not currently enabled by default
    (gh#syncthing/syncthing#804).
* Sat Mar 18 2017 sor.alexei@meowr.ru
- Update to version 0.14.24:
  * lib/sync: Fix a race in unlocker logging
    (gh#syncthing/syncthing#3884).
  * Make links and log messages refer to https instead of http
    where possible (gh#syncthing/syncthing#3976).
  * The default number of parallel file processing routines per
    directory is now two (previously one), and the number of
    simultaneously outstanding network requests has been increased.
  * The UI now contains buttons to pause or resume all directories
    with a single action.
* Thu Feb 16 2017 sor.alexei@meowr.ru
- Update to version 0.14.23 (changes since 0.14.21):
  * Leading and trailing spaces are no longer stripped in the GUI
    password field (gh#syncthing/syncthing#3935)
  * The GUI shows remaining amount of data to sync per directory
    (gh#syncthing/syncthing#3908).
  * There should no longer be empty entries in the global log
    (gh#syncthing/syncthing#3933).
  * Weak hashing is now by default only enabled when it makes sense
    from a performance point of view (gh#syncthing/syncthing#3938).
* Mon Feb  6 2017 sor.alexei@meowr.ru
- Update to version 0.14.21 (changes since 0.14.19):
  * There is now a warning when adding a directory that is a parent
    of an existing directory (gh#syncthing/syncthing#3197).
  * Using -logfile flag together with -no-restart now causes an
    error instead of silently failing (gh#syncthing/syncthing#3912).
  * Weak hashing is now disabled completely when the threshold
    percentage is > 100 (gh#syncthing/syncthing#3891).
  * Rate limiting now actually works on ARM64 builds again
    (gh#syncthing/syncthing#3921).
  * Fix an issue where UPnP port allocations would be incorrect
    under some circumstances (gh#syncthing/syncthing#3924).
  * Weak hashing is a bit faster and allocates less memory.
  * The hashing performance reported at startup now includes weak
    hashing.
  * The GUI "network error" dialogue no longer shows up as easily
    in some scenarios when using Syncthing behind a reverse proxy.
* Mon Jan 16 2017 sor.alexei@meowr.ru
- Update to version 0.14.19:
  * Changing bandwidth rate limits now takes effect immediately
    without restart (gh#syncthing/syncthing#3846)
  * The event log (-audit) can now be directed to stderr for
    piping into an another application
    (gh#syncthing/syncthing#3859).
  * A panic on directory listing at startup has been fixed
    (gh#syncthing/syncthing#3584).
  * When a directory is deleted, the .stfolder marker is also
    removed. The ignore file and .stversions directory are
    retained, if present (gh#syncthing/syncthing#3857).
  * Several scenarios where a device would get stuck with
    'not a directory' errors are now handled again
    (gh#syncthing/syncthing#3819).
  * Third party copyrights in the about box are now more up to
    date (gh#syncthing/syncthing#3839).
  * Hashing performance has been improved
    (gh#syncthing/syncthing#3861)
* Fri Jan  6 2017 sor.alexei@meowr.ru
- Update to version 0.14.18:
  * Fix connections to older Syncthing versions being no longer
    closed due to an unmarshalling message:
    'proto: wrong wireType = 2 for field BlockIndexes'
    (gh#syncthing/syncthing#3855).
* Tue Dec 27 2016 sor.alexei@meowr.ru
- Update to version 0.14.17:
  * Panics caused by corrupt on disc database are now better
    explained in the panic message (gh#syncthing/syncthing#3689).
  * Statically configured device addresses without port number now
    correctly defaulted to port 22000 again
    (gh#syncthing/syncthing#3817).
  * Inotify clients no longer cause 'invalid subpath' errors to be
    displayed (gh#syncthing/syncthing#3829).
  * Directories can now be paused (gh#syncthing/syncthing#215).
  * "Master" directories are now called "send only" in order to
    standardise on a terminology of sending and receiving changes
    (gh#syncthing/syncthing#2679).
  * Pausing devices and directories now persists across restarts
    (gh#syncthing/syncthing#3407).
  * A rolling checksum is used to identify and reuse blocks that
    have moved within a file (gh#syncthing/syncthing#3527).
  * Syncthing allows setting the type-of-service field on outgoing
    packets, configured by the advanced setting "trafficClass"
    (gh#syncthing/syncthing#3790).
  * Which device introduced another device is now visible in the
    GUI (gh#syncthing/syncthing#3809).
- Remove syncthing-go-1.4-compat.patch: becoming impossible to fix.
* Fri Dec 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.16:
  * Fix a regression introduced in v0.14.14: an 'invalid subpath'
    error on syncthing-inotify full directory sync trigger
    (gh#syncthing/syncthing#3829).
* Sat Dec 17 2016 sor.alexei@meowr.ru
- Update to version 0.14.15 (changes since 0.14.13):
  * Fix a security issue resulted in Syncthing accepting index
    entries for files like '../../foo', thus resulting in a path
    above the configured directory.
  * Fix a security issue resulted in symlinks be used to trick
    Syncthing and escape constraints of the configured directory by
    creating a symlink 'foo -> ../../' and then requesting the
    contents of 'foo/something' (boo#1016161).
    Syncing symlinks between v0.14.14+ and previous versions will
    not work.
  * The build no longer requires Go 1.7
    (gh#syncthing/syncthing#3753).
  * The wording in the GUI around "last file received" is now
    clearer (gh#syncthing/syncthing#3769).
- Remove syncthing-0.14.13-go-1.6-compat.patch: fixed upstream.
- Add syncthing-go-1.4-compat.patch: Fix Go 1.4 compatibility.
* Wed Dec  7 2016 sor.alexei@meowr.ru
- Update to version 0.14.13:
  * Improve CPU usage when scanning (gh#syncthing/syncthing#3394).
  * Fix writing config and .stignore files on filesystems without
    chmod support (gh#syncthing/syncthing#2472).
  * Language selector now stays above the bottom bar
    (gh#syncthing/syncthing#3758).
- Add syncthing-0.14.13-go-1.6-compat.patch: Fix Go 1.6 and older
  compatibility (commit 0dcf2f1).
* Mon Nov 28 2016 sor.alexei@meowr.ru
- Update to version 0.14.12:
  * A data race in the code that caused test failures, and possibly
    other inconsitencies, has been resolved
    (gh#syncthing/syncthing#3737).
  * Links in warning messages are now clickable in the GUI
    (gh#syncthing/syncthing#3241).
  * Files are now synced to the drive before committed to database,
    to avoid possible inconsistencies if a power failure occurs
    during syncing (gh#syncthing/syncthing#3711).
  * Log entries now mention directories by label in addition to the
    ID (gh#syncthing/syncthing#3724).
  * The default directory now has the directory ID "default" again,
    simplifying initial setup.
  * Retries for misconfigured relay setups are slowed down somewhat
    to be kinder on our relay pool infrastructure.
* Wed Nov 16 2016 sor.alexei@meowr.ru
- Update to version 0.14.11 (changes since 0.14.9):
  * Display of global and local state is clearer, especially in the
    presence of ignores (gh#syncthing/syncthing#3623).
  * GUI does not show "failed items" unless there are items that
    have failed (gh#syncthing/syncthing#3647).
  * Introducers can now remove devices that they introduced
    (gh#syncthing/syncthing#1015).
  * Syncthing now correctly reconnects to staticly configured
    relays (gh#syncthing/syncthing#3726).
  * strelaysrv: No longer crash with 'panic: send on closed channel'
    (gh#syncthing/syncthing#3718).
  * strelaysrv: Binding to a specific address now works better
    (gh#syncthing/syncthing#3682).
  * Directory information in the GUI now uses icons and tooltips
    (gh#syncthing/syncthing#3710).
  * Fixes to questionmark and asterisk handling in ignore patterns.
  * Re-add the "Black" theme.
  * Add debugging options for deadlocks.
* Sun Oct 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.9:
  * Documentation PDFs are fixed (gh#syncthing/syncthing#3651).
  * Browser error on first startup doesn't happen as easily anymore
    (gh#syncthing/syncthing#3619).
  * Syncthing compiles in Go versions older than 1.7 again
    (gh#syncthing/syncthing#3664).
  * Adding a directory using Long UNC path no longer causes stack
    overflow (but don't do that, it's not necessary)
    (gh#syncthing/syncthing#3577).
  * Update translations.
* Sat Oct  8 2016 sor.alexei@meowr.ru
- Update to version 0.14.8:
  * The monitor process now detects crashes due to the new hashing
    package and disables it on subsequent launch
    (gh#syncthing/syncthing#3613).
  * The two hash packages are benchmarked on startup and the
    fastest on is selected (gh#syncthing/syncthing#3614).
  * Directories are now correctly shown as out of sync when they
    miss only deleted files (gh#syncthing/syncthing#3588).
  * UPnP handling is corrected in the case where more than one
    router is detected (gh#syncthing/syncthing#3578).
  * Patterns with terminal slash (e.g., "dir/") now correctly
    ignore directory contents (gh#syncthing/syncthing#3639).
* Thu Sep 29 2016 sor.alexei@meowr.ru
- Update to version 0.14.7:
  * Faster (i.e., less CPU intensive) hashing on some Intel and
    ARM64 CPUs.
  * A more refined dark theme.
  * CORS headers in the API.
  * Updated set of default discovery servers.
  * Fix deadlock on device removal (gh#syncthing/syncthing#3596).
* Sat Sep 10 2016 sor.alexei@meowr.ru
- Update to version 0.14.6:
  * In sync percentages no longer go negative for large numbers of
    deleted files (gh#syncthing/syncthing#3496).
  * Files that were deleted and then ignored are no longer deleted
    on other devices that didn't ignore them
    (gh#syncthing/syncthing#3502).
  * Configuration is no longer moved away when perfoming an upgrade
    on a full drive (gh#syncthing/syncthing#3525).
* Tue Aug 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.5:
  * Improve completion percentage calculations
    (gh#syncthing/syncthing#3492, gh#syncthing/syncthing#3493).
  * A zero progress update interval doesn't drive up CPU usage
    during syncing any more (gh#syncthing/syncthing#3517).
  * Fix virtual modtime handling, now master directories no longer
    become spuriously out of sync (gh#syncthing/syncthing#3516).
  * Remove temporary index sorting databases from disk at startup,
    if left over after a hard stop (gh#syncthing/syncthing#3529).
  * Now automatic upgrade takes more care to not leave temporaries
    behind or remove the original in case of upgrade failure
    (gh#syncthing/syncthing#3500, gh#syncthing/syncthing#3530).
* Sun Aug 14 2016 sor.alexei@meowr.ru
- Update to version 0.14.4:
  * Timestamps are now compared with up to nanosecond precision and
    synced with up to microsecond precision, depending on the
    filesystem in use.
  * Restart is no longer needed to remove devices, unshare or
    reconfigure directories.
  * Now in sync percentage is weighted to directory size, not just
    average of directory completion.
  * Improve accessibility in the GUI.
  * Ignores and invalid file names are now handled correctly when
    delta indexes are being used.
  * Connection switching (relay->direct) no longer causes a crash.
  * Old index databases (v0.11-v0.12 and v0.13) are now properly
    cleaned away from disk.
  * Syncthing no longer claims a connection was from an ignored
    device when the device is just unknown.
* Thu Jul 28 2016 sor.alexei@meowr.ru
- Update to version 0.14.3:
  * Devices no longer get stuck in "out of sync" after a
    disconnection.
  * Syncthing no longer crashes when a connection is lost before
    index sending has started.
  * Temporary index databases are now created in the home (config)
    directory, not the system temporary directory.
* Wed Jul 27 2016 sor.alexei@meowr.ru
- Update to version 0.14.2 (changes since 0.14.0):
  * Implement "delta indexes", a backwards compatible protocol
    enhancement. Prior to delta indexes being implemented, full
    index information was exchanged at every connection start.
    With delta indexes, only index information that has changed
    since last contact is transferred.
  * Files that grow or shrink during scanning would result in
    conflicts or inconsistent data after synchronisation.
* Sat Jul 23 2016 sor.alexei@meowr.ru
- Update to version 0.14.0:
  * Respect address family for listen addresses in Discovery
    results.
  * Base the sync protocol, local discovery protocol and database
    format on protocol buffers.
  * Quickly detect other local devices on restart in local
    discovery.
  * Fix race condition causing a deadlock on directory addition.
  * Correctly format Anonymous Usage Reporting Preview.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 0.13.10:
  * Generated directory IDs are now lower case.
  * Syncthing now uses shorter temporary file names, alleviating
    issues on encfs.
  * Event IDs seen in /rest/system/events are now sequential again.
  * Tests now pass on when building on arm64.
  * Directories are now marked "stopped" when missing a path, and
    duplicate directory IDs are not accepted.
  * A stalling TLS handshake no longer blocks the connection service.
  * The global discovery server now correctly handle IPv6 announces
    over IPv4 and vice versa.
* Mon Jun 27 2016 sor.alexei@meowr.ru
- Update to version 0.13.9 (changes since 0.13.7)
  * The layout of the out of sync items dialog has been improved.
  * Directories are now sorted by label, falling back to ID when
    required.
  * Directory name completion now works for empty names.
  * Directories can now be symbolic links also when using
    ~-relative paths.
  * The discovered device addresses are now shown for disconnected
    devices.
- Enable systemd 215+ specifics on SLE 12 SP2+ and
  openSUSE Leap 42.2+.
* Fri Jun 17 2016 jacobwinski@gmail.com
- Update to version 0.13.7:
  * Fixes the issue with the GUI being grey on startup.
- Update to version 0.13.6:
  * v0.13.5 -no-upgrade build now requires gcc.
  * Favicon should not be animated.
  * Toggling HTTP/HTTPS breaks GUI/API.
  * Understand older/newer Hello messages.
  * Warnings on relay connectivity issues are reduced.
* Fri Jun  3 2016 sor.alexei@meowr.ru
- Update to version 0.13.5:
  * vendor: Update github.com/gobwas/glob.
  * cmd/syncthing: Fix upgrade of running syncthing from CLI.
  * cmd/syncthing: Be more explicit about how assets should be
    cached.
  * gui: Extract URL from translated string.
  * lib/connections: Handle wrapped connection in SetTCPOptions.
  * lib/relay: Correctly get IP from remote addr via proxy.
  * gui: Use favicon as indication for status.
  * gui: Fix editing devices.
  * gui: Show 'scanning' on unshared directories.
  * cmd/syncthing: Re-enable auto upgrade for dev builds.
  * lib/model, lib/stats: Keep track of folder's last scan time.
* Thu May 26 2016 sor.alexei@meowr.ru
- Update to version 0.13.4 (changes since 0.13.1):
  * lib/connections: Do not resolve addresses.
  * cmd/syncthing: Enforce stricter CSRF policy on /rest GET
    requests.
  * vendor: Replace github.com/jackpal/gateway with
    github.com/calmh/gateway.
  * lib/model: Leave temp file in place when final rename fails.
  * lib/model: Track puller creation times.
  * cmd/syncthing: Correctly set, parse and compare modified time
    HTTP headers.
  * lib/util: Add secure random numbers source.
  * lib/upgrade: Prefer a minor upgrade over a major.
  * cmd/syncthing: Do not modify events.
  * lib/model: Fix wild completion percentages.
  * cmd/syncthing: Use API to generate API Key and directory ID.
  * gui: Update translations.
  * Verbose log output (-verbose) and audit log (-audit) now
    contain information about changes to local files.
* Thu May 19 2016 liedke@rz.uni-mannheim.de
- Update to version 0.13.1:
  * lib/config: Don't migrate non-HTTPS-URL discovery servers to new
    path
  * gui, lib: Add missing licenses
  * lib/connections: Correctly add port to portless tcp:// URLs
* Wed May 18 2016 jengelh@inai.de
- Drop unnecessary systemd install-time dependencies. [bnc#980389]
  Only pass template units to preun (disable); no other actions
  are defined for them.
* Tue May 17 2016 sor.alexei@meowr.ru
- Update to version 0.13.0:
  * Devices now announce files that are in progress of being
    downloaded, in addition to those that are already complete.
    This means a device can serve parts of a file to other devices
    before it has completed the download itself.
  * Directory labels are now distinct from the directory ID.
    The intention is for the label to be human readable and for the
    ID to be machine readable and unique. When upgrading,
    directory IDs are not changed. However when creating new
    directories Syncthing will suggest a random, unique directory
    ID.
  * When receiving a connection attempt from an unknown device
    Syncthing will now show the name of that device, not only it's
    ID.
  * Syncthing will now manage port mappings on NAT-PMP compliant
    routers, in addition to the existing UPnP support.
  * Ignored files can now be tagged with the prefix (?d) to
    indicate that Syncthing may delete these files if they remain
    when deleting a directory. Ignore patterns use less memory by
    default.
  * The address for sync connections, both the listening side and
    for remote devices, can now be made IPv4- or IPv6-only. Use the
    tcp4:// or tcp6:// schemes to specify one or the other. The
    default tcp:// is still dual stack. Additionally, relays are
    now treated as listen addresses and set in the same
    configuration setting.
  * The directory settings dialog has been cleaned up.
  * The environment variable ALL_PROXY_NO_FALLBACK can be set to
    disable falling back to direct connections in the absence of a
    working proxy.
  * The "Syncing" complete percentage for remote devices may
    erroneously display more than 100%% (i.e. 156%% or 297%%) while a
    remote device is still synchronising.
  * Many, many bug fixes.
* Sat May  7 2016 sor.alexei@meowr.ru
- Update to version 0.12.23:
  * lib/upgrade: Enforce limits on download archives.
  * lib/upgrade: Auto upgrade signature should cover version & arch.
  * gui: angular and angular-translate updates.
* Sat Apr 16 2016 sor.alexei@meowr.ru
- Update to version 0.12.22 (boo#976937):
  * cmd/syncthing: Skip a calculation if timediff is zero.
* Fri Mar 25 2016 sor.alexei@meowr.ru
- Update to 0.12.21:
  * lib/model: Correct handling of multiple subs when scanning.
  * lib/model: Properly handle deleting multiple files when doing
    scans with subs.
  * Clarify UI stuff.
  * Increase contrast for readonly form controls in dark theme.
  * ui: Improve layout of footer on narrow screens.
  * lib/relay/client: Log relay client messages.
  * ui: Better accessibility for directory & device panels.
* Sun Mar  6 2016 sor.alexei@meowr.ru
- Update to 0.12.20:
  * Fix description-contains-tabs and improve description.
  * ui: Add a lock icon to the directory title for easy overview.
  * ui: Add html tooltips (title) to the directory path and
    syncthing version elements.
  * systemd: Add syncthing-resume.service.
  * Only test with -race on supported platforms.
* Thu Feb 18 2016 sor.alexei@meowr.ru
- Update to 0.12.19:
  * Return "No such object in the index" when /rest/db/file gets
    called on something that doesn't exist.
  * Swap the corsMiddleware and the csrfMiddleware to the
    unauthenticated OPTIONS requests are first processed.
  * Report versioning usage in usage report.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 0.12.18 (changes since 0.12.16):
  * Add -paths option to print config, key, database paths.
  * Handle null case for invalid ng-model value.
  * Use dialer in relay checks.
  * Minor refactoring.
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to 0.12.16:
  * Don't require restart for usage reporting changes.
  * Avoid spurious scans with inotify package.
* Sun Jan 17 2016 sor.alexei@meowr.ru
- Update to 0.12.15 (changes since 0.12.12):
  * Add support for themes.
  * Don't leak sendIndexes on disconnect.
  * Always run relaying when enabled.
  * Update 'Edit' menu to 'Action' menu.
  * Handle race within the job queue.
  * Improve API/GUI shutdown handling.
  * Don't crash on directory remove while pulling.
* Mon Jan 11 2016 sor.alexei@meowr.ru
- Update to 0.12.12:
  * Update kardianos/osext.
  * Change default max conflicts to 10.
  * Do not conflict copy conflict copies.
  * Do not allow in use CSRF tokens to expire.
  * Add relaying to main settings dialog.
  * Do not resolve destination address until we need to.
  * More fine grained locking in discovery cache.
  * Add STNODEFAULTFOLDER envvar to skip default directory
    creation on new install.
- Remove Go marcos usage for now.
* Thu Jan  7 2016 sor.alexei@meowr.ru
- Update to 0.12.11:
  * Remove windows specialisation from osutil.GetLans.
  * Ensure loaded config is free of duplicate devices.
  * Show device ID QR code from edit dialog.
  * Don't warn about failed ignores if directory is unhealthy.
  * Detect non-standard hash algo and stop directory.
  * Disallow adding duplicate device ID in GUI.
* Tue Dec 29 2015 sor.alexei@meowr.ru
- Update to 0.12.10:
  * Don't crash on stat error in ensureDir.
  * Consider tempfile when checking for free space.
  * Update kardianos/osext.
  * Remove fixed footer at first media break.
  * Update mtime of config file before upgrading.
  * Correct GUI asset dir handling.
* Sun Dec 20 2015 sor.alexei@meowr.ru
- Update to 0.12.9:
  * Example GUI override address.
  * Additional output on insufficient error.
  * Add command line option to open GUI.
  * Always exit via error select, making sure reader routine is exits.
  * Do not verify free space for files when directory
    MinDiskFreePct==0.
  * Edit device after accepting new connection.
* Mon Dec 14 2015 sor.alexei@meowr.ru
- Update to 0.12.8:
  * Correct type assertion in verbose logger, restart.
  * Remove Android hacks.
  * upnp: Use a separate error for the error unmarshalling.
* Tue Dec  8 2015 sor.alexei@meowr.ru
- Update to 0.12.7:
  * Filenames added to audit log in the LocalIndexUpdated event.
  * staticClient.connect(): don't handshake twice.
  * Fix STTRACE=http (it should use the http debug logger).
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 0.12.6 (changes since 0.12.4):
  * Update osext dependency.
  * Compact database on startup.
  * Do not chmod in Atomic on android.
  * Fix symlinks.
  * Generate ECDSA keys instead of RSA.
  * Take timeout into account when dialing.
  * Improve upgrade error messages.
  * Allow #urPreview to scroll in the browser.
  * New key for discovery-*-3.
  * Handle backoff on discovery.
* Mon Nov 23 2015 sor.alexei@meowr.ru
- Update to 0.12.4:
  * Warn the user if they're running with an insecure looking setup.
  * Add remaining scanning time.
  * Handle sparse files.
  * Improved relay handling.
* Mon Nov 16 2015 sor.alexei@meowr.ru
- Update to 0.12.3:
  * Fix address list in DeviceDiscovered, add debug prints.
  * Audit logins with new LoginAttempt event.
  * More local discovery URL debugging.
  * Made upgrade-system smarter.
  * Remove directory without restart.
  * Do not dirty blockmap key between lookups.
* Tue Nov 10 2015 sor.alexei@meowr.ru
- Update to 0.12.2:
  * Change a discovery server certificate.
  * Fix "INFO: bug: uncached path call" log output on first startup.
* Mon Nov  9 2015 sor.alexei@meowr.ru
- Update to 0.12.1:
  * Actually do negative caching on failed discovery lookups.
- Correct discovery port for SUSEfirewall rule.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 0.12.0.
* Fri Oct  2 2015 sor.alexei@meowr.ru
- Update to 0.11.26:
  * Do not check for free space on master directories.
  * Subscribing to events should not bump event ID.
  * Correctly report errors encountered parsing ignores.
  * Create missing directories when necessary ("dst stat dir: ..."
    error).
  * Add syncthing-inotify.service optional systemd dependency.
* Sun Sep 13 2015 sor.alexei@meowr.ru
- Update to 0.11.25:
  * Fix incorrect "out of disk space" error when pulling files.
* Sun Sep  6 2015 sor.alexei@meowr.ru
- Update to 0.11.24:
  * Correctly handle (?i) in ignores.
  * Adjust defaults for number of hashers based on OS.
  * Allow fractional free space percentages.
* Sun Aug 30 2015 sor.alexei@meowr.ru
- Update to 0.11.23:
  * Do not trust response header.
  * Allow -logfile on all platforms.
* Wed Aug 26 2015 sor.alexei@meowr.ru
- Update to 0.11.22:
  * Fix events timeout errors.
- Correct TCP and UDP ports once again.
* Sun Aug 23 2015 sor.alexei@meowr.ru
- Update to 0.11.21:
  * Recover from 'corrupted or incomplete CURRENT file' etc.
  * Retain standard streams over restart.
  * Add unit test for staggered versioning.
  * Newest first should be different from oldest first.
  * Fix time zone error in staggered versioning.
* Mon Aug 17 2015 sor.alexei@meowr.ru
- Update to 0.11.20:
  * Rename 'delete' to 'remove'.
  * Fix editing device address.
  * Use grid instead of three-column.
  * Stop directory when running out of disk space.
  * Remove double slashes in directives.
  * Change to Font Awesome icon font.
- Fix systemd service for openSUSE Leap 42.x and openSUSE 13.2.
- Fix SUSEfirewall rule by setting UDP ports as UDP ports.
* Sun Aug  9 2015 sor.alexei@meowr.ru
- Update to 0.11.19:
  * Properly rename config files during integration tests.
  * Add timeout for peek.
  * Handle multiple case insensitivity prefixes in ignores.
- Add a SUSEfirewall rule.
* Sun Aug  2 2015 sor.alexei@meowr.ru
- Update to 0.11.18:
  * Use protocol provided buffers for requests.
  * Update credits for dependencies.
* Tue Jul 28 2015 sor.alexei@meowr.ru
- Update to 0.11.17:
  * Determine conflict winner based on change type and modification
    time.
  * Optionally ignore remote deletes.
  * Add devices and directories without restart.
* Sun Jul 19 2015 jacobwinski@gmail.com
- update to 0.11.16:
  * Allow #editIgnores to scroll in browser.
  * Don't let folder ID escape into HTML tag ID:s.
  * Improve info text for device addresses.
* Wed Jul 15 2015 jacobwinski@gmail.com
- Update to 0.11.15 (changes since 0.11.13):
  * Fix advanced option saving.
  * Update protocol package.
  * Update panic instructions.
  * Remove one of two emits of events.DeviceConnected.
* Mon Jul  6 2015 sor.alexei@meowr.ru
- Update to 0.11.13 (changes since 0.11.11):
  * Show FolderErrors result in UI.
  * Fix CSRF tests.
  * Fix add device button being overlapped by footer.
  * Preserve setgid bit on local directories.
  * Implement "advanced configuration" dialog.
  * Add link to home page.
  * Use bootstrap grid instead of column-count:3 for aligning
    checkboxes.
* Mon Jun 29 2015 sor.alexei@meowr.ru
- Update to 0.11.11:
  * Serialize scans and pulls.
  * Do not rename duplicate directories.
  * Trim string slices upon loading config.
  * Make ping timeout configurable.
* Wed Jun 24 2015 sor.alexei@meowr.ru
- Update to 0.11.10:
  * Do not warn about irrelevant symlinks, print path to culprit.
  * Add label next to "Last file received".
  * Correct API response when resetting a directory.
  * Do not start model until services have been added.
  * Sanitize rescan interval values.
* Tue Jun 16 2015 sor.alexei@meowr.ru
- Update to 0.11.9:
  * Start directories before GUI/API.
  * Correctly handle nil error in verbose logging.
  * More resilient broadcast handling.
  * Add trash can file versioning.
  * Correctly set and clear errors for missing directories.
* Sun Jun  7 2015 sor.alexei@meowr.ru
- Update to 0.11.8:
  * Random number is too large for 32 bit archs.
  * Silence discovery warnings.
  * Fix missing languages.
- Remove /usr/sbin/rcsyncthing: service name is syncthing@$USER.
* Mon Jun  1 2015 sor.alexei@meowr.ru
- Update to 0.11.7:
  * Change permissions of newly created files and directories.
  * Make syncthing honour both the ignorePerms and FlagNoPermBits
    settings.
  * A performance fix for transfers of large files.
* Mon May 25 2015 sor.alexei@meowr.ru
- Update to 0.11.6:
    Set permanent UPnP lease when required.
    Show date and time for web GUI notification.
    UPnP discovery results must not be collected in a background goroutine.
    Be more lenient against errors when deleting.
* Sat May 16 2015 sor.alexei@meowr.ru
- Update to 0.11.5 (changes since 0.11.3):
  * Add unit test for overriding ignored files.
  * Use MD5 hash of filename for temporary file.
  * Only restart global discovery on UPnP change if it was enabled
    to start with.
  * Virtual mtime support for environments that don't support
    altering mtimes.
* Tue May 12 2015 sor.alexei@meowr.ru
- Update to 0.11.3:
  * Do not remove the file when renaming on a case-insensitive
    platform.
  * Distinguish files with same name but different extension in
    staggered versioner.
  * Reschedule the next scan interval.
  * Wait for stdout/stderr to close.
  * Use actual release version for release note link.
  * Set the execute bit on Windows executables.
  * Trigger pull check on remote index updates.
  * Implement upnpSvc.Stop().
  * Remove system/editor specific ignores.
* Thu May  7 2015 sor.alexei@meowr.ru
- Initial package.
